@@ -1000,7 +1000,7 @@ JSAutoCompleter.transformScopeOperator = function(expr, fname)
     var search = 0;
     for (;;)
     {
-        // Find the next occurrance of .%.
+        // Find the next occurrence of .%.
         var end = sexpr.indexOf(".%", search);
         if (end === -1)
             break;
@@ -1864,7 +1864,7 @@ function setCompletionsFromObject(out, object, context)
                 // The object is a large array. To avoid RangeErrors from
                 // `target.push.apply` and a slow `Object.getOwnPropertyNames`,
                 // we just skip this level ("length" is also on the prototype,
-                // and numeric property would get hidden later anyway).
+                // and numeric properties would get hidden later anyway).
             }
             else
             {
@@ -2390,6 +2390,14 @@ function autoCompleteEval(context, preExpr, spreExpr, preParsed, spreParsed, opt
             });
         }
 
+        if (!spreExpr)
+        {
+            // For global completions, hide results starting with a digit, since they conflict
+            // with typing numbers. An interested user would type 'window.<name>', anyway.
+            var reValid = /^[^0-9]/;
+            out.completions = out.completions.filter((x) => reValid.test(x));
+        }
+
         // Sort the completions, and avoid duplicates.
         // Note: If we make it possible to show both regular and hidden completions
         // at the same time, completions should shadow hiddenCompletions here.
