@@ -15,13 +15,14 @@ define([
     "firebug/lib/system",
     "firebug/lib/xpcom",
     "firebug/lib/object",
+    "firebug/lib/devtools",
     "firebug/chrome/tableRep",
     "firebug/console/console",
     "firebug/editor/editor",
     "firebug/editor/inlineEditor",
 ],
 function(Module, Rep, FirebugReps, Domplate, Locale, Dom, Win, Css, Str, Options, Menu, System,
-    Xpcom, Obj, TableRep, Console, Editor, InlineEditor) {
+    Xpcom, Obj, DevTools, TableRep, Console, Editor, InlineEditor) {
 
 // ********************************************************************************************* //
 // Constants
@@ -37,19 +38,7 @@ var Trace = FBTrace.to("DBG_COMMANDLINE");
 
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
-var ScratchpadManager;
-
-try
-{
-    var scope = {};
-    Cu.import("resource:///modules/devtools/scratchpad-manager.jsm", scope);
-    ScratchpadManager = scope.ScratchpadManager;
-}
-catch(ex)
-{
-    // Scratchpad does not exists (when using Seamonkey ...)
-}
-
+var ScratchpadManager = DevTools.ScratchpadManager;
 var storageScope = {}, StorageService;
 Cu.import("resource://firebug/storageService.js", storageScope);
 StorageService = storageScope.StorageService;
@@ -304,7 +293,7 @@ var CommandLineIncludeRep = domplate(TableRep,
             }
         ];
 
-        if (ScratchpadManager)
+        if (typeof ScratchpadManager.openScratchpad == "function")
         {
             items.push({
                 label: "commandline.label.OpenInScratchpad",
