@@ -43,6 +43,10 @@ DebuggerLib.unwrapDebuggeeValue = function(obj)
     if (typeof obj !== "object" || obj === null)
         return obj;
 
+    if (typeof obj.unsafeDereference != "function") {
+      return;
+    }
+
     return Wrapper.unwrapObject(obj.unsafeDereference());
 };
 
@@ -147,6 +151,17 @@ DebuggerLib.getObject = function(context, actorId)
         if (!actor && threadActor._pausePool)
             actor = threadActor._pausePool.get(actorId);
 
+        // Check also the youngest frame that contains objects
+        // living in the scope.
+        // We could also iterate all frames through: threadActor.framePool,
+        // but it could have an impact on performance since this method
+        // is called quite often. It would have to be tested carefully.
+        if (!actor && threadActor.youngestFrame &&
+            threadActor.youngestFrame.actor &&
+            threadActor.youngestFrame.actor.frameLifetimePool) {
+          actor = threadActor.youngestFrame.actor.frameLifetimePool.get(actorId);
+        }
+
         if (!actor)
             return null;
 
@@ -209,6 +224,11 @@ DebuggerLib.getThreadDebugger = function(context)
  */
 DebuggerLib.getThreadDebuggeeGlobalForContext = function(context, global)
 {
+    // Fx27+; this works even with cross-origin frames.
+    var dbg = DebuggerLib.getThreadDebugger(context);
+    if (dbg && dbg.makeGlobalObjectReference)
+        return dbg.makeGlobalObjectReference(global);
+
     var threadActor = DebuggerLib.getThreadActor(context.browser);
     if (!threadActor || !threadActor.globalDebugObject)
         return null;
@@ -369,6 +389,12 @@ DebuggerLib.isExecutableLine = function(context, location)
         return;
     }
 
+    if (!location.url)
+    {
+        TraceError.sysout("debuggerClient.isExecutableLine; ERROR No URL?");
+        return;
+    }
+
     // Set 'innermost' property to false to get any script that is presented
     // on the specified line (see also issue 7176).
     var query = {
@@ -541,7 +567,9 @@ DebuggerLib.breakNow = function(context)
         // but we might want to change what global to use here.
         var global = context.getCurrentGlobal();
         var dbgGlobal = this.getInactiveDebuggeeGlobal(context, global);
-        return dbgGlobal.evalInGlobal("debugger;");
+        return dbgGlobal.executeInGlobal ?
+            dbgGlobal.executeInGlobal("debugger;") :
+            dbgGlobal.evalInGlobal("debugger;");
     }
 };
 
