@@ -455,6 +455,12 @@ ScriptPanel.prototype = Obj.extend(BasePanel,
 
     showThisCompilationUnit: function(compilationUnit)
     {
+        if (!compilationUnit.getURL())
+        {
+            TraceError.sysout("scriptPanel.showThisCompilationUnit; no URL?");
+            return false;
+        }
+
         if (compilationUnit.getURL().lastIndexOf("chrome://", 0) === 0)
             return false;
 
@@ -1484,10 +1490,14 @@ ScriptPanel.prototype = Obj.extend(BasePanel,
     toggleDisableBreakpoint: function(line)
     {
         var currentUrl = this.getCurrentURL();
-        // create breakpoint if it doesn't exist
+
         var hasBreakpoint = BreakpointStore.hasBreakpoint(currentUrl, line);
         if (!hasBreakpoint)
-            BreakpointStore.addBreakpoint(currentUrl, line);
+        {
+            // Create disabled breakpoint if it doesn't exist yet and bail out.
+            BreakpointStore.addBreakpoint(currentUrl, line, undefined, undefined, true);
+            return;
+        }
 
         var isDisabled = BreakpointStore.isBreakpointDisabled(currentUrl, line);
         if (isDisabled)
@@ -1751,8 +1761,6 @@ ScriptPanel.prototype = Obj.extend(BasePanel,
         // before the ScriptPanel is initialized and adds itself to the DebuggerTool
         // as a listener.
 
-        Trace.sysout("scriptPanel.newSource; " + sourceFile.href, sourceFile);
-
         // New script has been appended, update the default location if necessary.
         // xxxHonza: Do not use this.navigate() method since it would fire "onPanelNavigate"
         // event and cause {@linke NavigationHistory} to be updated (issue 6950).
@@ -1764,7 +1772,7 @@ ScriptPanel.prototype = Obj.extend(BasePanel,
             this.location = this.getDefaultLocation();
 
             Trace.sysout("scriptPanel.newSource; this.location.getURL() = " +
-                this.location.getURL());
+                (this.location ? this.location.getURL() : "no url"));
 
             this.updateLocation(this.location);
             Firebug.chrome.syncLocationList();
@@ -1826,7 +1834,7 @@ ScriptPanel.prototype = Obj.extend(BasePanel,
 
         function failure(result, context)
         {
-            // We are mostly not interested in this evaluation error. It just polutes
+            // We are mostly not interested in this evaluation error. It just pollutes
             // the tracing console.
             // Trace.sysout("scriptPanel.populateInfoTip; ERROR " + result, result);
 
