@@ -4,6 +4,7 @@ define([
     "firebug/firebug",
     "firebug/lib/trace",
     "firebug/lib/object",
+    "firebug/lib/options",
     "firebug/lib/string",
     "firebug/lib/url",
     "firebug/lib/xpath",
@@ -18,7 +19,7 @@ define([
     "firebug/remoting/debuggerClient",
     "arch/compilationunit",
 ],
-function (Firebug, FBTrace, Obj, Str, Url, Xpath, Xpcom, Tool, ErrorStackTraceObserver,
+function (Firebug, FBTrace, Obj, Options, Str, Url, Xpath, Xpcom, Tool, ErrorStackTraceObserver,
     BreakpointStore, BreakpointTool, SourceFile, StackFrame, DebuggerLib,
     DebuggerClient, CompilationUnit) {
 
@@ -59,6 +60,7 @@ var versionComparator = Cc["@mozilla.org/xpcom/version-comparator;1"]
     .getService(Ci.nsIVersionComparator);
 var fx30 = (versionComparator.compare(appInfo.version, "30a1") >= 0 &&
     versionComparator.compare(appInfo.version, "30.*") <= 0);
+var fx35OrEarlier = (versionComparator.compare(appInfo.version, "36a1") < 0);
 
 var dynamicTypesMap = {
     "eval": CompilationUnit.EVAL,
@@ -75,6 +77,7 @@ var dynamicTypesMap = {
 function SourceTool(context)
 {
     this.context = context;
+    this.ignoreDynamicScripts = Options.get("ignoreDynamicScripts");
 }
 
 /**
@@ -152,13 +155,23 @@ SourceTool.prototype = Obj.extend(new Tool(),
     {
         // Ignore scripts generated from 'clientEvaluate' packets. These scripts are
         // created e.g. as the user is evaluating expressions in the watch window.
-        if (DebuggerLib.isFrameLocationEval(script.url))
+        if (script.introductionType === "debugger eval" ||
+            DebuggerLib.isFrameLocationEval(script.url))
         {
             Trace.sysout("sourceTool.addScript; A script ignored " + script.type +
                 ", " + script.url, script);
             return;
         }
 
+        // Reject dynamic scripts if the option to listen them is turned off.
+        if (this.ignoreDynamicScripts &&
+            dynamicTypesMap[script.introductionType] &&
+            script.introductionType !== "scriptElement") {
+            Trace.sysout("sourceTool.updateScriptFiles; dynamic script introduced and " +
+                "ignored as the user set the preference \"ignoreDynamicScripts\" to true");
+            return;
+        }
+
         // xxxHonza: Ignore inner scripts for now
         if (this.context.getSourceFile(script.url))
         {
@@ -166,6 +179,10 @@ SourceTool.prototype = Obj.extend(new Tool(),
             return;
         }
 
+        // There is no URL for e.g. event handler scripts.
+        if (!script.url)
+          script.url = this.context.getName() + "@" + script.actor;
+
         // Create a source file and append it into the context. This is the only
         // place where an instance of {@link SourceFile} is created.
         var sourceFile = new SourceFile(this.context, script.actor, script.url,
@@ -306,12 +323,17 @@ DynamicSourceCollector.prototype =
 {
     attach: function()
     {
+        if (this.sourceTool.ignoreDynamicScripts)
+            return;
+
         var dbg = DebuggerLib.getThreadDebugger(this.context);
 
         // Monkey patch the current debugger.
         this.originalOnNewScript = dbg.onNewScript;
 
         dbg.onNewScript = this.onNewScript.bind(this);
+        this.context.numberOfDynamicScripts = 0;
+        this.maxNumberOfDynamicScripts = Options.get("maxNumberOfDynamicScripts");
     },
 
     detach: function()
@@ -451,6 +473,16 @@ DynamicSourceCollector.prototype =
             this.context.addSourceFile(sourceFile);
         }
 
+        // If we reach the limit of dynamic scripts, we stop listening on dynamic script additions.
+        // This prevents unresponsive warnings on pages like ones using Polymer.
+        if (this.maxNumberOfDynamicScripts >= 0 &&
+            this.context.numberOfDynamicScripts > this.maxNumberOfDynamicScripts)
+        {
+            var dbg = DebuggerLib.getThreadDebugger(this.context);
+            if (dbg)
+                dbg.onNewScript = this.originalOnNewScript;
+        }
+
         // Register new script object in the source file object, before "newSource" event.
         // This way bp.params.dynamicHandler is set for dynamic breakpoints and filtered
         // out during standard breakpoint initialization within:
@@ -495,6 +527,9 @@ DynamicSourceCollector.prototype =
         }
 
         sourceFile.scripts.push(script);
+        // Keep the length of the first original source.
+        // It is used to optimize the comparison of two sources in computeDynamicUrl.
+        sourceFile.originalSourceLength = script.source ? script.source.text.length : undefined;
 
         // Initialize breakpoints for the new script.
         var bps = BreakpointStore.getBreakpoints(sourceFile.href);
@@ -505,8 +540,13 @@ DynamicSourceCollector.prototype =
     restoreBreakpoints: function(script)
     {
         var threadActor = DebuggerLib.getThreadActor(this.context.browser);
-        if (!threadActor._allowSource(script.url))
+        if (!allowSource(threadActor, script)) {
             return false;
+        }
+
+        // Firefox 38 removes the breakpointStore
+        if (!threadActor.breakpointStore)
+          return false;
 
         var endLine = script.startLine + script.lineCount - 1;
         for (var bp of threadActor.breakpointStore.findBreakpoints({url: script.url}))
@@ -611,13 +651,13 @@ function buildStackFrame(frame, context)
         // Use proper (dynamically generated) URL.
         stackFrame.href = sourceFile.href;
 
-        // xxxHonza: line numbers seem to be wrong for 'scriptElement' scripts,
-        // but only for those that are injected into the page using textContent
+        // Prior to Firefox 36, line numbers were wrong for dynamically injected
+        // 'scriptElement' scripts that don't refer to an external resource, e.g.:
         // var script = document.createElement("script");
         // script.textContent = source;
         // document.body.appendChild(scriptTag);
-        // https://bugzilla.mozilla.org/show_bug.cgi?id=982153
-        if (script.source.introductionType == "scriptElement")
+        // See https://bugzilla.mozilla.org/show_bug.cgi?id=982153.
+        if (fx35OrEarlier && script.source.introductionType == "scriptElement")
         {
             var element = DebuggerLib.unwrapDebuggeeValue(script.source.element);
             var src = element.getAttribute("src");
@@ -775,7 +815,7 @@ function computeDynamicUrl(script, context)
     // Workaround for issue 7521. Make sure dynamic scripts always have
     // unique URL if the source differs.
     // It solves the problem where eval on the same location (i.e. wrapped
-    // within a fucntion) is used to generate different scripts.
+    // within a function) is used to generate different scripts.
     var sourceFile = context.getSourceFile(uniqueUrl);
     if (sourceFile)
     {
@@ -786,12 +826,18 @@ function computeDynamicUrl(script, context)
             sourceFile.otherUniqueUrlsAtSameLocation = [uniqueUrl];
 
         // Lookup the matching source files.
+        var newScriptLength = script.source.text.length;
         var matchingSourceFileUrl = sourceFile.otherUniqueUrlsAtSameLocation.find((url) =>
         {
             var sf = context.getSourceFile(url);
-            return sf.scripts && sf.scripts.length > 0 &&
-                (sf.scripts[0].source === script.source ||
-                sf.scripts[0].source.text === script.source.text);
+
+            if (!sf.scripts || sf.scripts.length === 0)
+                return;
+
+            var curScript = sf.scripts[0];
+            return curScript.source === script.source ||
+                sf.originalSourceLength === newScriptLength &&
+                curScript.source.text === script.source.text;
         });
 
         if (matchingSourceFileUrl)
@@ -806,6 +852,7 @@ function computeDynamicUrl(script, context)
             sourceFile.uniqueUrlIndex = index;
             // Update the unique URL so it is really unique.
             uniqueUrl += " (" + index + ")";
+            context.numberOfDynamicScripts++;
             sourceFile.otherUniqueUrlsAtSameLocation.push(uniqueUrl);
         }
     }
@@ -833,6 +880,12 @@ function getElementId(script)
     return Xpath.getElementTreeXPath(element) + " " + attrName;
 }
 
+function allowSource(threadActor, script) {
+    return threadActor._allowSource ?
+        threadActor._allowSource(script.url) :
+        threadActor.sources.allowSource(script.source);
+}
+
 // ********************************************************************************************* //
 // Registration
 
