@@ -260,7 +260,7 @@ EventsPanel.prototype = Obj.extend(Firebug.Panel,
             return null;
         try
         {
-            // Pattern match on the occurance of '<minified name>.event.<funcName>.apply'.
+            // Pattern match on the occurrence of '<minified name>.event.<funcName>.apply'.
             var matches = /\b([a-zA-Z_$][a-zA-Z0-9_$]*)\.event\.(dispatch|handle)\.apply/.exec(src);
             var jqName = (matches && matches[1]) || "";
             dbgEnv = dbgEnv.find(jqName);
@@ -406,7 +406,7 @@ EventsPanel.prototype = Obj.extend(Firebug.Panel,
     getListeners: function(target)
     {
         var normal = this.getNormalEventListeners(target);
-        var disabled = this.getDisabledMap(this.context).get(target, []);
+        var disabled = this.getDisabledMap(this.context).get(target) || [];
 
         // Try to insert the disabled listeners at their previous positions. This will be
         // wrong in case listeners have been removed since those positions were recorded,
