@@ -91,7 +91,7 @@ DomplateTag.prototype =
      * Initializer for DOM templates. Called to create new Functions objects like TR, TD,
      * OBJLINK, etc. See defineTag
      *
-     * @param args keyword argments for the template, the {} brace stuff after the tag name,
+     * @param args keyword arguments for the template, the {} brace stuff after the tag name,
      *      eg TR({...}, TD(...
      * @param oldTag a nested tag, eg the TD tag in TR({...}, TD(...
      */
@@ -750,7 +750,7 @@ DomplateLoop.prototype = copyObject(DomplateTag.prototype,
         var iterName;
         if (this.iter instanceof Parts)
         {
-            // We have a function with optional aruments or just one variable
+            // We have a function with optional arguments or just one variable
             var part = this.iter.parts[0];
 
             // Join our function arguments or variables
@@ -868,7 +868,7 @@ function parseParts(str)
     if (!index)
     {
         // Double quotes in strings need to be escaped (see issue 6710)
-        return str.replace("\\", "\\\\", "g").replace('"', '\\"', "g");
+        return str.replace(/\\/g, "\\\\").replace(/"/g, '\\"');
     }
 
     // If we have data after our last matched index we append it here as the final step
@@ -1313,12 +1313,29 @@ function defineTags()
     }
 }
 
+// APIs for associating elements with data, future compatible with Firebug.next.
+// The data is currently stored as expandos on the elements, or in the case of
+// elements from unprivileged content, expandos on the elements' unwaived xray
+// wrappers. Note that the latter expandos are local to the current
+// compartment, and thus to Firebug when compartment_per_addon is set.
+Domplate.getElementData = function(elem, name)
+{
+    return elem[name];
+};
+
+Domplate.setElementData = function(elem, name, value)
+{
+    elem[name] = value;
+};
+
 // xxxHonza: Domplate is injected into FBL namespace only for backward
 // compatibility with extensions.
 // We need to mark this as deprecated.
 FBL.TAG = Domplate.TAG;
 FBL.FOR = Domplate.FOR;
 FBL.DomplateTag = Domplate.DomplateTag;
+FBL.getElementData = Domplate.getElementData;
+FBL.setElementData = Domplate.setElementData;
 
 defineTags(
     "a", "button", "br", "canvas", "col", "colgroup", "div", "fieldset", "form", "h1", "h2",
