@@ -229,7 +229,7 @@ var NetUtils =
             return file.postText;
 
         var limit = Options.get("netDisplayedPostBodyLimit");
-        if (file.postText.length > limit && !noLimit)
+        if (limit !== 0 && file.postText.length > limit && !noLimit)
         {
             return Str.cropString(file.postText, limit,
                 "\n\n... " + Locale.$STR("net.postDataSizeLimitMessage") + " ...\n\n");
@@ -240,7 +240,7 @@ var NetUtils =
 
     getResponseText: function(file, context)
     {
-        // The response can be also empty string so, check agains "undefined".
+        // The response can be also empty string so, check against "undefined".
         return (typeof(file.responseText) != "undefined") ?
             file.responseText :
             context.sourceCache.loadText(file.href, file.method, file);
@@ -371,7 +371,7 @@ var NetUtils =
      * The logic is as follows:
      * 1) If the request is an XHR, return 'xhr' as category
      * 2) Otherwise use the file extension to guess the MIME type.
-     *    This is prefered since MIME types in HTTP requests are often wrong.
+     *    This is preferred since MIME types in HTTP requests are often wrong.
      *    This part is based on the 'mimeExtensionMap' map.
      * 3) If the file extension is missing or unknown, try to get the MIME type
      *    from the HTTP request object.
@@ -389,7 +389,7 @@ var NetUtils =
      * The logic is as follows:
      * 1) If the request is an XHR, add 'xhr' as category
      * 2) Use the file extension to guess the MIME type.
-     *    This is prefered since MIME types in HTTP requests are often wrong.
+     *    This is preferred since MIME types in HTTP requests are often wrong.
      *    This part is based on the 'mimeExtensionMap' map.
      * 3) If the file extension is missing or unknown, try to get the MIME type
      *    from the HTTP request object.
@@ -408,7 +408,7 @@ var NetUtils =
             categories.push("xhr");
 
         // Guess mime-type according to the file extension. Using file extension
-        // is prefered way since mime-types in HTTP requests are often wrong.
+        // is preferred way since mime-types in HTTP requests are often wrong.
         var mimeType = this.getMimeType(null, file.href);
 
         // If no luck with file extension, let's try to get the mime-type from
@@ -538,7 +538,7 @@ var NetUtils =
 
         function cloneHeaders(headers)
         {
-            var newHeaders = [];
+            var newHeaders = new global.Array();
             for (var i=0; headers && i<headers.length; i++)
             {
                 var header = {name: headers[i].name, value: headers[i].value};
